// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KRUNNER_VERSION_H
#define KRUNNER_VERSION_H

#define KRUNNER_VERSION_STRING "6.23.0"
#define KRUNNER_VERSION_MAJOR 6
#define KRUNNER_VERSION_MINOR 23
#define KRUNNER_VERSION_PATCH 0
#define KRUNNER_VERSION ((6<<16)|(23<<8)|(0))

#endif
